#ifndef MY_CONFIG
#define MY_CONFIG

// Gerät hat keine Bedienelemente zum einstellen von Datum/Uhrzeit
// Die Uhrzeit wird auf die hier angegebenen Werte gesetzt wenn beim Einschalten der Jumper gesteckt ist
// Da die DS-Module eine interne Batterie haben, läuft die Zeit dann auch bei Stromausfall weiter
// Einmal pro Jahr Uhrzeit setzten, reicht aus

// Daten im PACKED-BCD-FORMAT angeben (einfach 0x vor die Zahlen setzten)
// Startzeit 01.01.2018 15:00 --> 0x01, 0x01, 0x18, 0x15, 0x00 
// Startzeit 12.01.2018 10:20 -->
static const __flash uint8_t start_tag    = 0x12;
static const __flash uint8_t start_monat  = 0x01;
static const __flash uint8_t start_jahr   = 0x18;
static const __flash uint8_t start_stunde = 0x10;
static const __flash uint8_t start_minute = 0x20;
// ---------------------------------------------------------------------------------------------------------------------
// Externe Hardware, Anschlüsse
// PC0...PC3 = NC, PC4 = I2C-SDA, PC5 = I2C-SCL
// PD0...PD3 = LEDs, PD4 = Jumper, PD5...PD7 = NC
// PB0...PB7 = NC
#define LED_RESTMUELL_AN    (PORTD |= (1<<PD0))
#define LED_GELBER_SACK_AN  (PORTD |= (1<<PD1))
#define LED_PAPIER_AN       (PORTD |= (1<<PD2))
#define LED_BIOTONNE_AN     (PORTD |= (1<<PD3))
#define LED_ALLE_AN         (PORTD |= (1<<PD0 | 1<<PD1 | 1<<PD2 | 1<<PD3))
#define LED_RESTMUELL_AUS   (PORTD &= ~(1<<PD0))
#define LED_GELBER_SACK_AUS (PORTD &= ~(1<<PD1))
#define LED_PAPIER_AUS      (PORTD &= ~(1<<PD2))
#define LED_BIOTONNE_AUS    (PORTD &= ~(1<<PD3))
#define LED_ALLE_AUS        (PORTD &= ~(1<<PD0 | 1<<PD1 | 1<<PD2 | 1<<PD3))

#define READ_JUMPER         (PIND & (1<<PD4))

#define INIT_IOPORT         DDRD = 0b11101111; \
                            PORTD= 0b11110000;
// ---------------------------------------------------------------------------------------------------------------------
// Entsprechende LED ist Dauer-An wenn morgen Müllabfuhr kommt und blinkt wenn heute Abholung
// Falls es anders rum gewünscht ist, "#define BLINK_AM_ABFUHRTAG" auskommentieren
#define BLINK_AM_ABFUHRTAG
// ---------------------------------------------------------------------------------------------------------------------
// Bitdefinitionen für Tonnen / LED-Status
// Je 2 Bit pro Tonne = (4 Tonnen = 1Byte)
// Nr  Bit  Tonnen
// 7   0    MORGEN KEINE BIOTONNE
// 6   0    HEUTE KEINE BIOTONNE
//
// 5   0    MORGEN KEIN PAPIER
// 4   1    HEUTE PAPIER
//
// 3   1    MORGEN GELBER SACK
// 2   0    HEUTE KEIN GELBER SACK
//
// 1   1    MORGEN RESTMÜLL     -> Ungenutzte Kombination
// 0   1    HEUTE RESTMÜLL      -> gibt nur 3 Möglichkeiten

// Bits Statusbyte
#define HEUTE_RESTMUELL     0
#define MORGEN_RESTMUELL    1
#define HEUTE_GELBER_SACK   2
#define MORGEN_GELBER_SACK  3
#define HEUTE_PAPIER        4
#define MORGEN_PAPIER       5
#define HEUTE_BIOTONNE      6
#define MORGEN_BIOTONNE     7
// ---------------------------------------------------------------------------------------------------------------------
// Typedef für Datum, Tonnendaten der Müllabfuhr Format PACKED BCD
typedef struct {
  uint8_t  tag;                 // Tag 1...31 (PACKED BCD)
  uint8_t  monat;               // Monat 1...12 (PACKED BCD)
  uint8_t  status;              // Status aus obigen DEFS
} abfuhr_t;
// ---------------------------------------------------------------------------------------------------------------------
#define TABELLE_ENDE        0   // Ende-Kennzeichen Tabelle

// Hier die Abfuhrtermine für dieses Jahr definieren
// Einen Tag VOR der Abfuhr, Definitionen "MORGEN_XXX" nutzen
// Am Tag der Abfuhr "HEUTE_XXX"
// Bei mehreren Tonnendaten, diese verodern
// Tag, Monat PACKED-BCD-Format... (Vor Tag, Monat einfach ein "0x" setzten)
// 01.01 --> 0x01, 0x01
// 23.12 --> 0x23, 0x12
static const __flash abfuhr_t abfuhrtabelle[] = {
  // Tabelle im FLASH
  { 0x01, 0x01, (1<<MORGEN_GELBER_SACK) },
  { 0x02, 0x01, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x03, 0x01, (1<<HEUTE_RESTMUELL) },
  { 0x08, 0x01, (1<<MORGEN_BIOTONNE) },
  { 0x09, 0x01, (1<<HEUTE_BIOTONNE) },
  { 0x14, 0x01, (1<<MORGEN_GELBER_SACK) },
  { 0x15, 0x01, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x16, 0x01, (1<<HEUTE_RESTMUELL) },
  { 0x22, 0x01, (1<<MORGEN_BIOTONNE) },
  { 0x23, 0x01, (1<<HEUTE_BIOTONNE) },
  { 0x28, 0x01, (1<<MORGEN_GELBER_SACK | 1<<MORGEN_PAPIER) },
  { 0x29, 0x01, (1<<HEUTE_GELBER_SACK | 1<<HEUTE_PAPIER | 1<<MORGEN_RESTMUELL) },
  { 0x30, 0x01, (1<<HEUTE_RESTMUELL) },
  { 0x05, 0x02, (1<<MORGEN_BIOTONNE) },
  { 0x06, 0x02, (1<<HEUTE_BIOTONNE) },
  { 0x12, 0x02, (1<<MORGEN_GELBER_SACK) },
  { 0x13, 0x02, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x14, 0x02, (1<<HEUTE_RESTMUELL) },
  { 0x19, 0x02, (1<<MORGEN_BIOTONNE) },
  { 0x20, 0x02, (1<<HEUTE_BIOTONNE) },
  { 0x25, 0x02, (1<<MORGEN_GELBER_SACK) },
  { 0x26, 0x02, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x27, 0x02, (1<<HEUTE_RESTMUELL) },
  { 0x28, 0x02, (1<<MORGEN_PAPIER) },
  { 0x01, 0x03, (1<<HEUTE_PAPIER) },
  { 0x05, 0x03, (1<<MORGEN_BIOTONNE) },
  { 0x06, 0x03, (1<<HEUTE_BIOTONNE) },
  { 0x11, 0x03, (1<<MORGEN_GELBER_SACK) },
  { 0x12, 0x03, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x13, 0x03, (1<<HEUTE_RESTMUELL) },
  { 0x19, 0x03, (1<<MORGEN_BIOTONNE) },
  { 0x20, 0x03, (1<<HEUTE_BIOTONNE) },
  { 0x25, 0x03, (1<<MORGEN_GELBER_SACK) },
  { 0x26, 0x03, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x27, 0x03, (1<<HEUTE_RESTMUELL) },
  { 0x28, 0x03, (1<<MORGEN_PAPIER) },
  { 0x29, 0x03, (1<<HEUTE_PAPIER) },
  { 0x03, 0x04, (1<<MORGEN_BIOTONNE) },
  { 0x04, 0x04, (1<<HEUTE_BIOTONNE) },
  { 0x08, 0x04, (1<<MORGEN_GELBER_SACK) },
  { 0x09, 0x04, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x10, 0x04, (1<<HEUTE_RESTMUELL) },
  { 0x16, 0x04, (1<<MORGEN_BIOTONNE) },
  { 0x17, 0x04, (1<<HEUTE_BIOTONNE) },
  { 0x22, 0x04, (1<<MORGEN_GELBER_SACK) },
  { 0x23, 0x04, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x24, 0x04, (1<<HEUTE_RESTMUELL) },
  { 0x29, 0x04, (1<<MORGEN_PAPIER) },
  { 0x30, 0x04, (1<<HEUTE_PAPIER) },
  { 0x01, 0x05, (1<<MORGEN_BIOTONNE) },
  { 0x02, 0x05, (1<<HEUTE_BIOTONNE) },
  { 0x06, 0x05, (1<<MORGEN_GELBER_SACK) },
  { 0x07, 0x05, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x08, 0x05, (1<<HEUTE_RESTMUELL) },
  { 0x14, 0x05, (1<<MORGEN_BIOTONNE) },
  { 0x15, 0x05, (1<<HEUTE_BIOTONNE) },
  { 0x21, 0x05, (1<<MORGEN_GELBER_SACK) },
  { 0x22, 0x05, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x23, 0x05, (1<<HEUTE_RESTMUELL) },
  { 0x28, 0x05, (1<<MORGEN_BIOTONNE) },
  { 0x29, 0x05, (1<<HEUTE_BIOTONNE) },
  { 0x03, 0x06, (1<<MORGEN_GELBER_SACK | 1<<MORGEN_PAPIER) },
  { 0x04, 0x06, (1<<HEUTE_GELBER_SACK | 1<<HEUTE_PAPIER | 1<<MORGEN_RESTMUELL | 1<<MORGEN_BIOTONNE) },
  { 0x05, 0x06, (1<<HEUTE_RESTMUELL | 1<<HEUTE_BIOTONNE) },
  { 0x11, 0x06, (1<<MORGEN_BIOTONNE) },
  { 0x12, 0x06, (1<<HEUTE_BIOTONNE) },
  { 0x17, 0x06, (1<<MORGEN_GELBER_SACK) },
  { 0x18, 0x06, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL | 1<<MORGEN_BIOTONNE) },
  { 0x19, 0x06, (1<<HEUTE_RESTMUELL | 1<<HEUTE_BIOTONNE) },
  { 0x25, 0x06, (1<<MORGEN_BIOTONNE) },
  { 0x26, 0x06, (1<<HEUTE_BIOTONNE) },
  { 0x01, 0x07, (1<<MORGEN_GELBER_SACK) },
  { 0x02, 0x07, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL | 1<<MORGEN_BIOTONNE) },
  { 0x03, 0x07, (1<<HEUTE_RESTMUELL | 1<<HEUTE_BIOTONNE | 1<<MORGEN_PAPIER) },
  { 0x04, 0x07, (1<<HEUTE_PAPIER) },
  { 0x09, 0x07, (1<<MORGEN_BIOTONNE) },
  { 0x10, 0x07, (1<<HEUTE_BIOTONNE) },
  { 0x15, 0x07, (1<<MORGEN_GELBER_SACK) },
  { 0x16, 0x07, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL | 1<<MORGEN_BIOTONNE) },
  { 0x17, 0x07, (1<<HEUTE_RESTMUELL | 1<<HEUTE_BIOTONNE) },
  { 0x23, 0x07, (1<<MORGEN_BIOTONNE) },
  { 0x24, 0x07, (1<<HEUTE_BIOTONNE) },
  { 0x29, 0x07, (1<<MORGEN_GELBER_SACK) },
  { 0x30, 0x07, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL | 1<<MORGEN_BIOTONNE) },
  { 0x31, 0x07, (1<<HEUTE_RESTMUELL | 1<<HEUTE_BIOTONNE | 1<<MORGEN_PAPIER) },
  { 0x01, 0x08, (1<<HEUTE_PAPIER) },
  { 0x06, 0x08, (1<<MORGEN_BIOTONNE) },
  { 0x07, 0x08, (1<<HEUTE_BIOTONNE) },
  { 0x12, 0x08, (1<<MORGEN_GELBER_SACK) },
  { 0x13, 0x08, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL | 1<<MORGEN_BIOTONNE) },
  { 0x14, 0x08, (1<<HEUTE_RESTMUELL | 1<<HEUTE_BIOTONNE) },
  { 0x20, 0x08, (1<<MORGEN_BIOTONNE) },
  { 0x21, 0x08, (1<<HEUTE_BIOTONNE) },
  { 0x26, 0x08, (1<<MORGEN_GELBER_SACK) },
  { 0x27, 0x08, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL | 1<<MORGEN_BIOTONNE) },
  { 0x28, 0x08, (1<<HEUTE_RESTMUELL | 1<<HEUTE_BIOTONNE | 1<<MORGEN_PAPIER) },
  { 0x29, 0x08, (1<<HEUTE_PAPIER) },
  { 0x03, 0x09, (1<<MORGEN_BIOTONNE) },
  { 0x04, 0x09, (1<<HEUTE_BIOTONNE) },
  { 0x09, 0x09, (1<<MORGEN_GELBER_SACK) },
  { 0x10, 0x09, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x11, 0x09, (1<<HEUTE_RESTMUELL) },
  { 0x17, 0x09, (1<<MORGEN_BIOTONNE) },
  { 0x18, 0x09, (1<<HEUTE_BIOTONNE) },
  { 0x23, 0x09, (1<<MORGEN_GELBER_SACK) },
  { 0x24, 0x09, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x25, 0x09, (1<<HEUTE_RESTMUELL | 1<<MORGEN_PAPIER) },
  { 0x26, 0x09, (1<<HEUTE_PAPIER) },
  { 0x01, 0x10, (1<<MORGEN_BIOTONNE) },
  { 0x02, 0x10, (1<<HEUTE_BIOTONNE) },
  { 0x07, 0x10, (1<<MORGEN_GELBER_SACK) },
  { 0x08, 0x10, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x09, 0x10, (1<<HEUTE_RESTMUELL) },
  { 0x15, 0x10, (1<<MORGEN_BIOTONNE) },
  { 0x16, 0x10, (1<<HEUTE_BIOTONNE) },
  { 0x21, 0x10, (1<<MORGEN_GELBER_SACK) },
  { 0x22, 0x10, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x23, 0x10, (1<<HEUTE_RESTMUELL | 1<<MORGEN_PAPIER) },
  { 0x24, 0x10, (1<<HEUTE_PAPIER) },
  { 0x29, 0x10, (1<<MORGEN_BIOTONNE) },
  { 0x30, 0x10, (1<<HEUTE_BIOTONNE) },
  { 0x04, 0x11, (1<<MORGEN_GELBER_SACK) },
  { 0x05, 0x11, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x06, 0x11, (1<<HEUTE_RESTMUELL) },
  { 0x12, 0x11, (1<<MORGEN_BIOTONNE) },
  { 0x13, 0x11, (1<<HEUTE_BIOTONNE) },
  { 0x18, 0x11, (1<<MORGEN_GELBER_SACK) },
  { 0x19, 0x11, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x20, 0x11, (1<<HEUTE_RESTMUELL) },
  { 0x25, 0x11, (1<<MORGEN_PAPIER) },
  { 0x26, 0x11, (1<<HEUTE_PAPIER | 1<<MORGEN_BIOTONNE) },
  { 0x27, 0x11, (1<<HEUTE_BIOTONNE) },
  { 0x02, 0x12, (1<<MORGEN_GELBER_SACK) },
  { 0x03, 0x12, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x04, 0x12, (1<<HEUTE_RESTMUELL) },
  { 0x10, 0x12, (1<<MORGEN_BIOTONNE) },
  { 0x11, 0x12, (1<<HEUTE_BIOTONNE) },
  { 0x16, 0x12, (1<<MORGEN_BIOTONNE) },
  { 0x17, 0x12, (1<<HEUTE_GELBER_SACK | 1<<MORGEN_RESTMUELL) },
  { 0x18, 0x12, (1<<HEUTE_RESTMUELL) },
  { 0x26, 0x12, (1<<MORGEN_BIOTONNE) },
  { 0x27, 0x12, (1<<HEUTE_BIOTONNE) },
  // Tabelle abschließen
  {TABELLE_ENDE, TABELLE_ENDE, TABELLE_ENDE} 
};
// ---------------------------------------------------------------------------------------------------------------------
#endif
