#include <util/twi.h>
#include "ds3231.h"

//I2C Adresse DS3231
#define DS_I2CADR_R   0b11010001    // Für Lesezugriffe
#define DS_I2CADR_W   0b11010000    // Für Schreibzugriffe

// ---------------------------------------------------------------------------------------------------------------------
// Öffentliche Funktion
// ---------------------------------------------------------------------------------------------------------------------
// Liest ein Register des DS3231 aus und gibt es zurück
// Übergeben werden muß Registernummer bzw. der Name aus "ds3231.h"
// Die Daten vom DS liegen IMMER im PACKED BCD FORMAT vor
uint8_t DSReadRegister (DS_REG Register)
{
  uint8_t RetVal;
  
  TWCR = (1<<TWINT)|(1<<TWSTA)|(1<<TWEN);     // Startbedingung
  while (!(TWCR & (1<<TWINT)));               // senden
  TWDR = DS_I2CADR_W;                         // Schreibzugriff
  TWCR = (1<<TWINT) | (1<<TWEN);              // DS3231
  while (!(TWCR & (1<<TWINT)));
  TWDR = Register;                            // Registeradresse senden
  TWCR = (1<<TWINT) | (1<<TWEN);
  while (!(TWCR & (1<<TWINT)));
  TWCR = (1<<TWINT)|(1<<TWSTA)|(1<<TWEN);     // Startbedingung
  while (!(TWCR & (1<<TWINT)));               // wiederholen
  TWDR = DS_I2CADR_R;                         // Lesezugriff
  TWCR = (1<<TWINT) | (1<<TWEN);              // DS3231
  while (!(TWCR & (1<<TWINT)));
  TWCR = (1<<TWINT)|(1<<TWEN);                // NACK senden / Byte empfangen
  while (!(TWCR & (1<<TWINT)));    
  RetVal = TWDR;
  while(!(TWCR & (1<<TWINT)));
  TWCR = (1<<TWINT)|(1<<TWEN)|(1<<TWSTO);     // Stopbedingung
  while (TWCR & (1<<TWINT));
  return RetVal;
}
// ---------------------------------------------------------------------------------------------------------------------
// Schreibt "Wert" in das Register "Register" des DS
// übergebener Wert muß wie für den DS üblich im PACKED BCD FORMAT vorliegen
// "Register" muß Registernummer oder Bezeichner aus "ds3231.h" sein
void DSWriteRegister (DS_REG Register, uint8_t Wert)
{
  TWCR = (1<<TWINT)|(1<<TWSTA)|(1<<TWEN);     // Startbedingung
  while (!(TWCR & (1<<TWINT)));               // senden
  TWDR = DS_I2CADR_W;                         // Schreibzugriff
  TWCR = (1<<TWINT) | (1<<TWEN);              // DS3231
  while (!(TWCR & (1<<TWINT)));
  TWDR = Register;                            // Registeradresse senden
  TWCR = (1<<TWINT) | (1<<TWEN);
  while (!(TWCR & (1<<TWINT)));
  TWDR = Wert;                                // Wert senden
  TWCR = (1<<TWINT) | (1<<TWEN);
  while (!(TWCR & (1<<TWINT)));
  TWCR = (1<<TWINT)|(1<<TWEN)|(1<<TWSTO);     // Stopbedingung
  while (TWCR & (1<<TWINT));
}
// ---------------------------------------------------------------------------------------------------------------------
