#include <avr/io.h>
#include <avr/interrupt.h>
#include <util/delay.h>
#include "config.h"
#include "ds3231.h"
#include "timer0.h"

// ---------------------------------------------------------------------------------------------------------------------
// Startinit
// Initialisiert Ports und Hardware
// Wenn Jumper gesteckt, Startuhrzeit aus Flash (config.h) übertragen in den DS
// LEDs 10 mal blinken lassen
// danach zum Test des 1Stunden Timers 1h LEDs an / 1h LEDs aus in Endlosschleife
static void avr_init (void)
{
  uint8_t tmp;
  uint8_t cnt;
  
  INIT_IOPORT;
  INIT_TWBR;
  INIT_TIMER0;
  sei();
  
  if (READ_JUMPER == 0) {
    tmp=start_tag;
    DSWriteRegister(DS_DATE, tmp);
    tmp=start_monat;
    DSWriteRegister(DS_MONTH, tmp);
    tmp=start_jahr;
    DSWriteRegister(DS_YEAR, tmp);
    DSWriteRegister(DS_SECONDS, 0x00);
    tmp=start_stunde;
    DSWriteRegister(DS_HOURS, tmp);
    tmp=start_minute;
    DSWriteRegister(DS_MINUTES, tmp);
    
    for (cnt=10; cnt>0; cnt--) {
      LED_ALLE_AN;
      _delay_ms(1000);
	    LED_ALLE_AUS;
      _delay_ms(1000);
    }
    
    while (1) {
      ticker_start();
      LED_ALLE_AN;
      while (ticker_get_status() == TICKER_COUNT) _delay_ms(1000);
      ticker_start();
      LED_ALLE_AUS;
      while (ticker_get_status() == TICKER_COUNT) _delay_ms(1000);
    }
  }
}
// ---------------------------------------------------------------------------------------------------------------------
// Übergabe: Pointer auf p_data, muß gefüllt sein mit heutigem Datum (tag monat)
// Rückgabe: DATEN_OK wenn für Heute Abfuhrdaten vorliegen, sonst DATEN_LEER
//           in p_data.status Abfuhrdaten für Heute
#define DATEN_OK    0
#define DATEN_LEER  1

static uint8_t get_data (abfuhr_t *p_data)
{
  uint16_t cnt;

  for (cnt=0; ; cnt++) {
    if ((abfuhrtabelle[cnt].tag == TABELLE_ENDE) && (abfuhrtabelle[cnt].monat == TABELLE_ENDE)) return DATEN_LEER;
    if ((abfuhrtabelle[cnt].tag == p_data->tag) && (abfuhrtabelle[cnt].monat == p_data->monat)) {
      p_data->status = abfuhrtabelle[cnt].status;
      return DATEN_OK;
    }
  }
}
// ---------------------------------------------------------------------------------------------------------------------
// Normalfunktion:
// aktuelles Datum vom DS abholen, prüfen on für aktuelles Datum Abholdaten in Tabelle hinterlegt sind
// Falls nein, alle LEDs aus, ca. eine Stunde warten und von vorn
// Falls ja, LEDs eine ca. Stunde lang ansteuern und von vorn
int main (void)
{
  abfuhr_t  data;
    
  // Init, bleibt dort "hängen" wenn Jumper gesteckt ist
  avr_init();

  while (1) {
    // Datum aus DS lesen und in data speichern (Format PACKED BCD)
    data.tag = DSReadRegister(DS_DATE);
    data.monat = DSReadRegister(DS_MONTH);
    // Abfuhrdaten für aktuelles Datum holen
    // Falls für aktuelles Datum keine Daten vorliegen, alle LEDs aus, eine Stunde warten
    if ((get_data(&data)) == DATEN_LEER) {
      LED_ALLE_AUS;
      ticker_start();
      while (ticker_get_status() == TICKER_COUNT) _delay_ms(1000);
    }
    
    // Es liegen Daten vor
    else {
      ticker_start();
      while (ticker_get_status() == TICKER_COUNT) {
        // Passende LEDs 500ms einschalten wenn heute oder morgen Abholung
        LED_ALLE_AUS;
        if ((data.status & (1<<HEUTE_BIOTONNE)) || (data.status & (1<<MORGEN_BIOTONNE))) LED_BIOTONNE_AN;
        if ((data.status & (1<<HEUTE_GELBER_SACK)) || (data.status & (1<<MORGEN_GELBER_SACK))) LED_GELBER_SACK_AN;
        if ((data.status & (1<<HEUTE_PAPIER)) || (data.status & (1<<MORGEN_PAPIER))) LED_PAPIER_AN;
        if ((data.status & (1<<HEUTE_RESTMUELL)) || (data.status & (1<<MORGEN_RESTMUELL))) LED_RESTMUELL_AN;
        _delay_ms(500);
        // je nach definition in config.h 
        // LED am Abfuhrtag blinken lassen und am Vortag dauer-an
        // oder am Tag vor der Abfuhr blinken und am Abholtag dauer-an 
#ifdef BLINK_AM_ABFUHRTAG
        if (data.status & (1<<HEUTE_BIOTONNE)) LED_BIOTONNE_AUS;
        if (data.status & (1<<HEUTE_GELBER_SACK)) LED_GELBER_SACK_AUS;
        if (data.status & (1<<HEUTE_PAPIER)) LED_PAPIER_AUS;
        if (data.status & (1<<HEUTE_RESTMUELL)) LED_RESTMUELL_AUS;
        _delay_ms(500);
#else
        if (data.status & (1<<MORGEN_BIOTONNE)) LED_BIOTONNE_AUS;
        if (data.status & (1<<MORGEN_GELBER_SACK)) LED_GELBER_SACK_AUS;
        if (data.status & (1<<MORGEN_PAPIER)) LED_PAPIER_AUS;
        if (data.status & (1<<MORGEN_RESTMUELL)) LED_RESTMUELL_AUS;
        _delay_ms(500);
#endif
      }
    }
  }
}
